@@ -4,6 +4,7 @@
 #include <config.h>
 
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/open.h>
 
 #include <glibtop/sysdeps.h>
@@ -727,6 +728,50 @@ glibtop_get_proc_map_l (glibtop *server, glibtop_proc_map *buf,
 	return retval;
 }
 
+glibtop_open_files_entry *
+glibtop_get_proc_open_files_l (glibtop *server, glibtop_proc_open_files *buf,
+                               pid_t pid)
+{
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	glibtop_open_files_entry * retval = (glibtop_open_files_entry *) 0;
+	param_buf.buf_pid = pid;
+
+	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_OPEN_FILES), 0);
+
+	/* If neccessary, we ask the server for the requested
+	 * feature. If not, we call the sysdeps function. */
+
+	if ((server->flags & _GLIBTOP_INIT_STATE_SERVER) &&
+	    (server->features & (1 << GLIBTOP_SYSDEPS_PROC_OPEN_FILES)))
+	{
+		retval = glibtop_call_l (server, GLIBTOP_CMND_PROC_OPEN_FILES,
+				         send_size, send_ptr,
+				         sizeof (glibtop_proc_open_files), buf);
+	} else {
+#if (!GLIBTOP_SUID_PROC_OPEN_FILES)
+		retval = glibtop_get_proc_open_files_s (server, buf, pid);
+#else
+		errno = ENOSYS;
+		glibtop_error_io_r (server, "glibtop_get_proc_open_files");
+#endif
+	}
+
+	/* Make sure that all required fields are present. */
+
+	if (buf->flags & server->required.proc_open_files)
+		_glibtop_missing_feature (server, "proc_open_files", buf->flags,
+					  &server->required.proc_open_files);
+
+	/* Now we can return. */
+
+	return retval;
+}
+
 glibtop_mountentry *
 glibtop_get_mountlist_l (glibtop *server, glibtop_mountlist *buf,
                          int all_fs)
