@@ -1,4 +1,4 @@
-/* $Id: write.c,v 1.15 2004/03/04 15:29:12 hadess Exp $ */
+/* $Id: write.c,v 1.17 2005/02/15 12:48:33 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,6 +24,7 @@
 #include <config.h>
 
 #include <glibtop/write.h>
+#include <glibtop/error.h>
 #include "libgtop-i18n.h"
 
 /* Writes some data to server. */
@@ -48,5 +49,5 @@ glibtop_write_l (glibtop *server, size_t size, void *buf)
 	}
 
 	if (ret < 0)
-		glibtop_error_io_r (server, ngettext ("write %d byte", "write %d bytes", size), size);
+		glibtop_error_io_r (server, ngettext ("wrote %d byte", "wrote %d bytes", size), size);
 }
