@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.4 2003/10/20 15:19:46 hadess Exp $ */
+/* $Id: proclist.c,v 1.7 2004/10/04 11:57:05 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 #include <glibtop.h>
 #include <glibtop/proclist.h>
 
-static const unsigned long _glibtop_sysdeps_proclist = 
+static const unsigned long _glibtop_sysdeps_proclist =
 (1 << GLIBTOP_PROCLIST_NUMBER) + (1 << GLIBTOP_PROCLIST_TOTAL) +
 (1 << GLIBTOP_PROCLIST_SIZE);
 
@@ -50,7 +50,7 @@ glibtop_init_proclist_s (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
 	struct procsinfo pinfo;
 	int count, total;
@@ -59,6 +59,8 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	pid_t current;
 	int result;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_PROCLIST), 0);
+
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	for( count = total = 0, current = 0
@@ -116,7 +118,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 				{
 					continue;
 				}
-				
+
 				break;
 
 			case GLIBTOP_KERN_PROC_PGRP:
@@ -184,7 +186,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 
 				break;
 		}
-	
+
 		if (count >= BLOCK_COUNT)
 		{
 			/* The following call to g_realloc will be
